const axios = require("axios");

import Vue from 'vue';
import Vuex from 'vuex';
import router from '../router'
//import modules from './modules';

Vue.use(Vuex);

/* const GET_PROJECT_USER = GET_PROJECT_USER;
const GET_ALL_PROJECTS = GET_ALL_PROJECTS;
const CHECK_LOGIN = CHECK_LOGIN;
const SET_COOKIE = SET_COOKIE;
const SET_STATIC_PAGES = SET_STATIC_PAGES; */


export default new Vuex.Store({
  //  modules,
  state: {
    cookie: null,
    logged: false,
    project: null,
    projectMembers: null,
    projects: [],
    staticPages: null,
  },

  mutations: {
    SET_PROJECTS(state, projects) {
      state.projects = projects;
    },
    SET_PROJECT(state, project) {
      state.project = project;
    },
    SET_PROJECT_MEMBERS(state, projectMembers) {
      state.projectMembers = projectMembers;
    },
    SET_LOGGED(state, payload) {
      state.logged = payload;
    },
    SET_COOKIE(state, cookie) {
      state.cookie = cookie
    },
    SET_STATIC_PAGES(state, staticPages) {
      state.staticPages = staticPages
    }
  },

  actions: {
    async GET_ALL_PROJECTS({ commit }) {
      await axios
        .get("http://localhost:8000/api/projects/")
        .then((response) => {
          const orderedProjects = response.data.sort((a, b) => new Date(b.created_on) - new Date(a.created_on));
          commit("SET_PROJECTS", orderedProjects)
        })
        .catch((error) => {
          throw error;
        });
    },
    async GET_STATIC_PAGES({ commit }) {
      await axios
        .get("http://localhost:8000/api/aide/")
        .then((response) => (commit("SET_STATIC_PAGES", response.data)))
        .catch((error) => {
          throw error;
        });
    },
    GET_PROJECT({ commit }, project_slug) {
      axios
        .get(`http://localhost:8000/api/projet/${project_slug}/project`)
        .then((response) => commit("SET_PROJECT", response.data))
        .catch((error) => {
          throw error;
        });
    },
    GET_PROJECT_USER({ commit }, project_slug) {
      axios
        .get(`http://localhost:8000/api/projet/${project_slug}/utilisateurs`)
        .then((response) => (commit("SET_PROJECT_MEMBERS", response.data.members)))
        .catch((error) => {
          throw error;
        });
    },
    CHECK_LOGIN({ commit }, payload) {
      if (payload.username && payload.password) {
        axios
          .post("http://localhost:8000/api/login/", {
            username: payload.username,
            password: payload.password,
          })
          .then(() => (commit("SET_LOGGED", true), router.push("/")))
          .catch((error) => {
            throw error;
          });
      }
    },
    GET_COOKIE({ commit }, name) {
      let cookieValue = null;

      if (document.cookie && document.cookie !== "") {
        const cookies = document.cookie.split(";");
        for (let i = 0; i < cookies.length; i++) {
          const cookie = cookies[i].trim();

          // Does this cookie string begin with the name we want?
          if (cookie.substring(0, name.length + 1) === name + "=") {
            cookieValue = decodeURIComponent(cookie.substring(name.length + 1));

            break;
          }
        }
      }
      commit("SET_COOKIE", cookieValue);
    },
  }

});
